@@ -2,6 +2,7 @@ import logging
 from typing import Tuple, List
 
 import torch as to
+from torch import nn
 from torch.utils.data import DataLoader
 
 from message_passing_nn.data.graph_dataset import GraphDataset
@@ -15,8 +16,6 @@ class DataPreprocessor(Preprocessor):
     def train_validation_test_split(self,
                                     dataset: List[Tuple[to.Tensor, to.Tensor, to.Tensor]],
                                     batch_size: int,
-                                    maximum_number_of_nodes: int,
-                                    maximum_number_of_features: int,
                                     validation_split: float = 0.2,
                                     test_split: float = 0.1) -> Tuple[DataLoader, DataLoader, DataLoader]:
         test_index, validation_index = self._get_validation_and_test_indexes(dataset,
@@ -64,6 +63,14 @@ class DataPreprocessor(Preprocessor):
             flattened_tensor = DataPreprocessor._pad_zeros(flattened_tensor, desired_size)
         return flattened_tensor
 
+    @staticmethod
+    def normalize(tensor: to.Tensor, device: str) -> to.Tensor:
+        if tensor.size()[0] > 1:
+            normalizer = nn.BatchNorm1d(tensor.size()[1], affine=False).to(device)
+            return normalizer(tensor)
+        else:
+            return tensor
+
     @staticmethod
     def _pad_zeros(flattened_tensor: to.Tensor, desired_size: int) -> to.Tensor:
         size_difference = abs(len(flattened_tensor) - desired_size)
