@@ -1,6 +1,7 @@
 from abc import ABCMeta, abstractmethod
 from typing import Any, Tuple, List
 
+import torch as to
 from torch.utils.data import DataLoader
 
 
@@ -12,10 +13,8 @@ class Preprocessor(metaclass=ABCMeta):
     @abstractmethod
     def train_validation_test_split(dataset: Any,
                                     batch_size: int,
-                                    maximum_number_of_nodes: int,
-                                    maximum_number_of_features: int,
-                                    validation_split: float = 0.2,
-                                    test_split: float = 0.1) -> Tuple[DataLoader, DataLoader, DataLoader]:
+                                    validation_split: float,
+                                    test_split: float) -> Tuple[DataLoader, DataLoader, DataLoader]:
         pass
 
     @staticmethod
@@ -25,5 +24,10 @@ class Preprocessor(metaclass=ABCMeta):
 
     @staticmethod
     @abstractmethod
-    def flatten(tensors: List[Any], desired_size: Any = 0) -> Any:
+    def flatten(tensors: to.Tensor, desired_size: Any = 0) -> to.Tensor:
+        pass
+
+    @staticmethod
+    @abstractmethod
+    def normalize(tensors: to.Tensor, device: str) -> to.Tensor:
         pass
